.. _fluent_pages.adminui.utils:

fluent_pages.adminui.utils
==========================

.. automodule:: fluent_pages.adminui.utils

.. autofunction:: fluent_pages.adminui.utils.get_page_admin_url

.. autofunction:: fluent_pages.adminui.utils.get_current_edited_page
